@@ -1,4 +1,10 @@
 module Token : sig
+  module Comment : sig
+    type t =
+      | Lines of string list
+      | Legacy
+  end
+
   type t =
     | Atom          of Atom.t
     | Quoted_string of string
@@ -7,9 +13,10 @@ module Token : sig
     | Sexp_comment
     | Eof
     | Template of Template.t
+    | Comment of Comment.t
 end
 
-type t = Lexing.lexbuf -> Token.t
+type t = with_comments:bool -> Lexing.lexbuf -> Token.t
 
 module Error : sig
   type t =
@@ -21,6 +28,8 @@ end
 
 val error : ?delta:int -> Lexing.lexbuf -> string -> 'a
 
+val invalid_dune_or_jbuild : Lexing.lexbuf -> 'a
+
 val escaped_buf : Buffer.t
 
 exception Error of Error.t
